@@ -10,7 +10,7 @@
 #endif
 
 {- |
-   Copyright  : Copyright (C) 2006-2015 Bjorn Buckwalter
+   Copyright  : Copyright (C) 2006-2018 Bjorn Buckwalter
    License    : BSD3
 
    Maintainer : bjorn@buckwalter.se
@@ -20,7 +20,7 @@
 Provides a 'Functor' instance for 'Dimensional'.
 
 Note that this instance is dubious, because it allows you to break the dimensional abstraction. See 'dmap' for more information.
- 
+
 Note that, while this instance overlaps with that given for 'Dimensionless', it is confluent with that instance.
 
 Note that this is an orphan instance.
@@ -28,11 +28,12 @@ Note that this is an orphan instance.
 module Numeric.Units.Dimensional.Functor where
 
 import Numeric.Units.Dimensional
+import Prelude
 
 -- | A 'Functor' instance for 'Dimensional'.
 --
 -- Note that this instance is dubious, because it allows you to break the dimensional abstraction. See 'dmap' for more information.
--- 
+--
 -- Note that, while this instance overlaps with that given for 'Dimensionless', it is confluent with that instance.
 --
 -- Note that this is an orphan instance.
